@@ -703,11 +703,10 @@ property_changed_cb (BonoboListener    *listener,
 
 	window = EOG_WINDOW (user_data);
 
-	if (!g_strcasecmp (event_name, "Bonobo/Property:change:window/title"))
+	if (!g_strcasecmp (event_name, "window/title"))
 		gtk_window_set_title (GTK_WINDOW (window),
 				      BONOBO_ARG_GET_STRING (any));
-	else if (!g_strcasecmp (event_name,
-				"Bonobo/Property:change:window/status"))
+	else if (!g_strcasecmp (event_name, "window/status"))
 		gnome_appbar_set_status (GNOME_APPBAR (window->priv->statusbar),
 					 BONOBO_ARG_GET_STRING (any));		
 }
@@ -734,7 +733,7 @@ check_for_control_properties (EogWindow *window)
 	if (title != NULL) {
 		gtk_window_set_title (GTK_WINDOW (window), title);
 		g_free (title);
-		mask = g_strdup ("Bonobo/Property:change:window/title");
+		mask = g_strdup ("window/title");
 	} else {
 		g_warning (_("Control doesn't support window_title property."));
 		gtk_window_set_title (GTK_WINDOW (window), "Eye of Gnome");
@@ -748,7 +747,7 @@ check_for_control_properties (EogWindow *window)
 					 title);
 		g_free (title);
 		/* append status_text property to list of properties to listen */
-		temp = g_strjoin (",", mask, "Bonobo/Property:change:window/status", NULL);
+		temp = g_strjoin (",", mask, "window/status", NULL);
 		g_free (mask);
 		mask = temp;
 	} else {
@@ -757,10 +756,12 @@ check_for_control_properties (EogWindow *window)
 
 	/* register for further changes */
 	if (mask) {
-		g_print ("add listener: %s\n", mask);
 		bonobo_event_source_client_add_listener (pb, 
 							 (BonoboListenerCallbackFn)property_changed_cb,
-							 mask, NULL, window);
+							 mask, &ev, window);
+		if (BONOBO_EX (&ev))
+			g_warning ("add_listener failed '%s'",
+				   bonobo_exception_get_text (&ev));
 		g_free (mask);
 	} 
 
@@ -822,7 +823,7 @@ get_viewer_control (GnomeVFSURI *uri, GnomeVFSFileInfo *info)
 	
  ctrl_error:
 	if (BONOBO_EX (&ev))
-		g_error ("%s", bonobo_exception_get_text (&ev));
+		g_warning ("%s", bonobo_exception_get_text (&ev));
 
 	CORBA_exception_free (&ev);
 
@@ -986,7 +987,15 @@ add_control_to_ui (EogWindow *window, Bonobo_Control control)
 					       "eog");
 		bonobo_object_release_unref (prop_control, &ev);
 	}
-	
+
+	/* enable view menu */
+	/* FIXME: We should check if the component adds anything to 
+	 *        the menu, so that we don't view an empty menu.
+	 */
+	bonobo_ui_engine_xml_set_prop (bonobo_window_get_ui_engine (BONOBO_WINDOW (window)),
+				       "/menu/View",
+				       "hidden", "0",
+				       "eog");
 
 	CORBA_exception_free (&ev);
 
@@ -1023,7 +1032,6 @@ eog_window_open (EogWindow *window, const char *text_uri)
 
 	/* obtain file infos */
 	info = gnome_vfs_file_info_new ();
-	g_print ("URI: %s\n", gnome_vfs_uri_to_string (uri, GNOME_VFS_URI_HIDE_NONE));
 	result = gnome_vfs_get_file_info_uri (uri, info,
 					      GNOME_VFS_FILE_INFO_DEFAULT |
 					      GNOME_VFS_FILE_INFO_FOLLOW_LINKS |
@@ -1033,6 +1041,8 @@ eog_window_open (EogWindow *window, const char *text_uri)
 		return FALSE;
 	}
 	
+	control = CORBA_OBJECT_NIL;
+
 	/* get appropriate control */
 	if (info->type == GNOME_VFS_FILE_TYPE_REGULAR)
 		control = get_viewer_control (uri, info);
@@ -1046,9 +1056,11 @@ eog_window_open (EogWindow *window, const char *text_uri)
 		return FALSE;
 	}
 
-	/* add it to the user interface */
-	add_control_to_ui (window, control);
-	bonobo_object_release_unref (control, NULL);
+	if (control != CORBA_OBJECT_NIL) {
+		/* add it to the user interface */
+		add_control_to_ui (window, control);
+		bonobo_object_release_unref (control, NULL);
+	}
 
 	/* clean up */
 	gnome_vfs_file_info_unref (info);
