@@ -56,10 +56,6 @@ struct _EogImageViewPrivate {
 	gboolean               zoom_fit;
 };
 
-enum {
-	LAST_SIGNAL
-};
-
 enum {
 	PROP_INTERPOLATION,
 	PROP_DITHER,
@@ -78,8 +74,6 @@ enum {
 static BonoboControl* property_control_get_cb (BonoboPropertyControl *property_control,
 					       int page_number, void *closure);
 
-static guint eog_image_view_signals [LAST_SIGNAL];
-
 static GObjectClass *eog_image_view_parent_class;
 
 static GNOME_EOG_Image
